@@ -10,10 +10,8 @@ from rest_framework_extensions.key_constructor.constructors import KeyConstructo
 
 class QueryListParamsKeyBit(bits.AllArgsMixin, bits.KeyBitDictBase):
     def get_source_dict(self, params, view_instance, view_method, request, args, kwargs):
-        data = {
-            k: request.query_params.getlist(k) for k in request.GET.keys()
-        }
-        data['renderer_type'] = request.accepted_media_type
+        data = {k: request.query_params.getlist(k) for k in request.GET.keys()}
+        data["renderer_type"] = request.accepted_media_type
         return data
 
 
@@ -29,25 +27,21 @@ cache_key_constructor = CacheKeyConstructor()
 
 class CacheResponse(decorators.CacheResponse):
     def process_cache_response(
-            self,
-            view_instance,
-            view_method,
-            request,
-            args,
-            kwargs,
+        self,
+        view_instance,
+        view_method,
+        request,
+        args,
+        kwargs,
     ):
         key = self.calculate_key(
-            view_instance=view_instance,
-            view_method=view_method,
-            request=request,
-            args=args,
-            kwargs=kwargs
+            view_instance=view_instance, view_method=view_method, request=request, args=args, kwargs=kwargs
         )
 
-        cache_control = request.headers.get('cache-control', 'default').split(',')
+        cache_control = request.headers.get("cache-control", "default").split(",")
 
         # TODO: accept and handler others directives, such as: no-store, must-revalidate
-        if 'no-cache' in cache_control:
+        if "no-cache" in cache_control:
             valid_cache_control = True
             response_dict = None
         else:
@@ -61,9 +55,9 @@ class CacheResponse(decorators.CacheResponse):
 
             if not response.status_code >= 400 or self.cache_errors:
                 expiration_date = now() + timedelta(seconds=self.timeout)
-                response['Expires'] = handlers.format_date_time(expiration_date.timestamp())
+                response["Expires"] = handlers.format_date_time(expiration_date.timestamp())
                 if valid_cache_control and cache_control:
-                    response['Cache-Control'] = f'max-age={self.timeout}'
+                    response["Cache-Control"] = f"max-age={self.timeout}"
 
                 response_dict = (
                     response.rendered_content,
@@ -83,12 +77,12 @@ class CacheResponse(decorators.CacheResponse):
 
             cache_hit = True
 
-        response['X-Cache'] = 'HIT' if cache_hit else 'MISS'
+        response["X-Cache"] = "HIT" if cache_hit else "MISS"
 
-        if not hasattr(response, '_closable_objects'):
+        if not hasattr(response, "_closable_objects"):
             response._closable_objects = []
 
         return response
 
 
-cache_response = CacheResponse
+cache_response = CacheResponse  # pylint: disable=invalid-name
